==> interceptable-0.1.0.tar.gz: lib/src/builder/writer/interceptable_writer.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:analyzer/dart/element/element.dart';
import 'package:build/src/builder/build_step.dart';
import 'package:glob/glob.dart';
import 'package:interceptable/src/annotation/enable_interceptable.dart';
import 'package:interceptable/src/builder/object/cache_object.dart';
import 'package:interceptable/src/builder/template/interceptable_template.dart';
import 'package:interceptable/src/builder/util/cache_utils.dart';
import 'package:mustache/mustache.dart';
import 'package:source_gen/source_gen.dart';

class InterceptableWriter extends GeneratorForAnnotation<EnableInterceptable> {
  @override
  generateForAnnotatedElement(
    Element element,
    ConstantReader annotation,
    BuildStep buildStep,
  ) async {
    final List<String> interceptableCache = [];
    final String packageName = buildStep.inputId.package;

    // init folder
    final String generationFolder = "${Directory.current.path}/lib/generated";
    Directory(generationFolder).deleteSync(recursive: true);
    Directory(generationFolder).createSync(recursive: true);

    // clean up folder

    final interceptableCacheAssetIds = await buildStep
        .findAssets(
          Glob("**/*.interceptable_cache.dart"),
        )
        .toList();

    for (var assetId in interceptableCacheAssetIds) {
      interceptableCache.add((await buildStep.readAsString(assetId)).trim());
    }

    final decodedInterceptableCache = interceptableCache
        .map((e) => CacheUtils.decode(e))
        .map((e) => e.first)
        .map((e) => json.decode(e))
        .map((e) => CacheObject.fromJson(e))
        .toList();

    for (var cache in decodedInterceptableCache) {
      File(cache.generatedPath).writeAsStringSync(cache.code);
    }

    return Template(interceptable_template).renderString({
      "caches": decodedInterceptableCache,
      "packageName": packageName,
    });
  }
}

==> interceptable-0.2.0.tar.gz: lib/src/builder/writer/interceptable_writer.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:analyzer/dart/element/element.dart';
import 'package:build/src/builder/build_step.dart';
import 'package:glob/glob.dart';
import 'package:interceptable/src/annotation/enable_interceptable.dart';
import 'package:interceptable/src/builder/object/cache_object.dart';
import 'package:interceptable/src/builder/template/interceptable_template.dart';
import 'package:interceptable/src/builder/util/cache_utils.dart';
import 'package:mustache/mustache.dart';
import 'package:source_gen/source_gen.dart';

class InterceptableWriter
    extends GeneratorForAnnotation<UseEnableInterceptable> {
  @override
  generateForAnnotatedElement(
    Element element,
    ConstantReader annotation,
    BuildStep buildStep,
  ) async {
    final List<String> interceptableCache = [];
    final String packageName = buildStep.inputId.package;

    // init folder
    final String generationFolder = "${Directory.current.path}/lib/generated";
    Directory(generationFolder).deleteSync(recursive: true);
    Directory(generationFolder).createSync(recursive: true);

    // clean up folder

    final interceptableCacheAssetIds = await buildStep
        .findAssets(
          Glob("**/*.interceptable_cache.dart"),
        )
        .toList();

    for (var assetId in interceptableCacheAssetIds) {
      interceptableCache.add((await buildStep.readAsString(assetId)).trim());
    }

    final decodedInterceptableCache = interceptableCache
        .map((e) => CacheUtils.decode(e))
        .map((e) => e.first)
        .map((e) => json.decode(e))
        .map((e) => CacheObject.fromJson(e))
        .toList();

    for (var cache in decodedInterceptableCache) {
      File(cache.generatedPath).writeAsStringSync(cache.code);
    }

    return Template(interceptable_template).renderString({
      "caches": decodedInterceptableCache,
      "packageName": packageName,
    });
  }
}
